# Generated by roxygen2: do not edit by hand

S3method(plot,box)
S3method(plot,riskyr)
S3method(print,summary.riskyr)
S3method(summary,riskyr)
export(FFTrees_riskyr)
export(accu)
export(as_pb)
export(as_pc)
export(comp_FDR)
export(comp_FOR)
export(comp_NPV)
export(comp_PPV)
export(comp_acc)
export(comp_accu_freq)
export(comp_accu_prob)
export(comp_comp_pair)
export(comp_complement)
export(comp_complete_prob_set)
export(comp_err)
export(comp_fart)
export(comp_freq)
export(comp_freq_freq)
export(comp_freq_prob)
export(comp_min_N)
export(comp_mirt)
export(comp_popu)
export(comp_ppod)
export(comp_prob)
export(comp_prob_freq)
export(comp_prob_prob)
export(comp_sens)
export(comp_spec)
export(freq)
export(init_num)
export(init_pal)
export(init_txt)
export(is_complement)
export(is_extreme_prob_set)
export(is_freq)
export(is_integer)
export(is_matrix)
export(is_perc)
export(is_prob)
export(is_suff_prob_set)
export(is_valid_prob_pair)
export(is_valid_prob_set)
export(is_valid_prob_triple)
export(num)
export(pal)
export(pal_bw)
export(pal_bwp)
export(pal_crisk)
export(pal_kn)
export(pal_mbw)
export(pal_mod)
export(pal_org)
export(pal_rgb)
export(pal_unikn)
export(pal_vir)
export(plot_area)
export(plot_bar)
export(plot_crisk)
export(plot_curve)
export(plot_fnet)
export(plot_icons)
export(plot_mosaic)
export(plot_plane)
export(plot_prism)
export(plot_tab)
export(plot_tree)
export(popu)
export(prob)
export(read_popu)
export(riskyr)
export(riskyr.guide)
export(scenarios)
export(txt)
export(txt_TF)
export(txt_org)
export(write_popu)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,col2rgb)
importFrom(grDevices,dev.size)
importFrom(grDevices,grey)
importFrom(grDevices,rgb)
importFrom(grDevices,trans3d)
importFrom(grDevices,xy.coords)
importFrom(graphics,abline)
importFrom(graphics,arrows)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,box)
importFrom(graphics,curve)
importFrom(graphics,grid)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,mtext)
importFrom(graphics,par)
importFrom(graphics,persp)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,rug)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(graphics,title)
importFrom(stats,predict)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(stats,smooth.spline)
importFrom(utils,browseVignettes)
importFrom(utils,vignette)
